@@ -5,27 +5,23 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.4.4.20-10-4
-description: Array.prototype.filter doesn't visit expandos
+es5id: 15.4.4.20-5-2
+description: Array.prototype.filter - thisArg is Object
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-
-  var callCnt = 0;
+  var res = false;
+  var o = new Object();
+  o.res = true;
   function callbackfn(val, idx, obj)
   {
-    callCnt++;
+    return this.res;
   }
-  var srcArr = [1,2,3,4,5];
-  srcArr["i"] = 10;
-  srcArr[true] = 11;
 
-  var resArr = srcArr.filter(callbackfn);
-  if(callCnt == 5)
-  {
+  var srcArr = [1];
+  var resArr = srcArr.filter(callbackfn,o);
+  if( resArr.length === 1)
     return true;
-  }
-
  }
 runTestCase(testcase);
