@@ -5,22 +5,25 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.4.4.14-5-22
+es5id: 15.4.4.14-9-a-17
 description: >
-    Array.prototype.indexOf - value of 'fromIndex' is an Object, which
-    has an own valueOf method
+    Array.prototype.indexOf - decreasing length of array causes index
+    property not to be visited
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
 
-        var fromIndex = {
-            valueOf: function () {
-                return 1;
-            }
-        };
+        var arr = [0, 1, 2, "last"];
 
+        Object.defineProperty(arr, "0", {
+            get: function () {
+                arr.length = 3;
+                return 0;
+            },
+            configurable: true
+        });
 
-        return [0, true].indexOf(true, fromIndex) === 1;
+        return -1 === arr.indexOf("last");
     }
 runTestCase(testcase);
