@@ -5,19 +5,24 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.4.4.17-5-13
-description: Array.prototype.some - Number object can be used as thisArg
+es5id: 15.4.4.17-8-2
+description: >
+    Array.prototype.some returns false if 'length' is 0 (subclassed
+    Array, length overridden to null (type conversion))
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-
-        var objNumber = new Number();
-
-        function callbackfn(val, idx, obj) {
-            return this === objNumber;
-        }
-
-        return [11].some(callbackfn, objNumber);
-    }
+  foo.prototype = new Array(1, 2, 3);
+  function foo() {}
+  var f = new foo();
+  f.length = null;
+  
+  function cb(){}
+  var i = f.some(cb);
+  
+  if (i === false) {
+    return true;
+  }
+ }
 runTestCase(testcase);
