@@ -5,17 +5,17 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.3.5.4_2-88gs
+es5id: 15.3.5.4_2-83gs
 description: >
     Strict mode - checking access to strict function caller from
     non-strict function (non-strict function declaration called by
-    strict Function.prototype.call(globalObject))
+    strict Function.prototype.apply(globalObject))
 flags: [noStrict]
 includes: [fnGlobalObject.js]
 ---*/
 
 function f() { return gNonStrict();};
-(function () {"use strict"; return f.call(fnGlobalObject()); })();
+(function () {"use strict"; return f.apply(fnGlobalObject()); })();
 
 
 function gNonStrict() {
