@@ -5,14 +5,19 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.12.1.1-g6-2
+es5id: 15.12.1.1-g4-4
 description: >
-    The JSON lexical grammer allows '' as a JSONEscapeCharacter after
-    '' in a JSONString
+    The JSON lexical grammar does not allow a JSONStringCharacter to
+    be any of the Unicode characters U+0018 thru U+001F
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-    return JSON.parse('"\\\\"')==='\\'; 
+  try {
+    JSON.parse('"\u0018\u0019\u001a\u001b\u001c\u001d\u001e\u001f"'); // invalid string characters should produce a syntax error
+    }
+  catch (e) {
+      if (e.name === 'SyntaxError') return true;
+      }
   }
 runTestCase(testcase);
