@@ -5,16 +5,16 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.2.3.3-4-54
+es5id: 15.2.3.3-4-134
 description: >
     Object.getOwnPropertyDescriptor returns data desc for functions on
-    built-ins (Array.prototype.every)
+    built-ins (Date.prototype.getUTCSeconds)
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-  var desc = Object.getOwnPropertyDescriptor(Array.prototype, "every");
-  if (desc.value === Array.prototype.every &&
+  var desc = Object.getOwnPropertyDescriptor(Date.prototype, "getUTCSeconds");
+  if (desc.value === Date.prototype.getUTCSeconds &&
       desc.writable === true &&
       desc.enumerable === false &&
       desc.configurable === true) {
