@@ -5,15 +5,13 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.2.3.12-3-13
-description: >
-    Object.isFrozen returns false for all built-in objects
-    (Number.prototype)
+es5id: 15.2.3.12-3-22
+description: Object.isFrozen returns false for all built-in objects (RangeError)
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-  var b = Object.isFrozen(Number.prototype);
+  var b = Object.isFrozen(RangeError);
   if (b === false) {
     return true;
   }
