@@ -5,19 +5,21 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.2.3.10-3-15
+info: The effect of preventExtentions must be testable by calling isExtensible
+es5id: 15.2.3.10-2
 description: >
-    Object.preventExtensions - named properties cannot be added into a
-    String object
+    Object.preventExtensions returns its arguments after setting its
+    extensible property to false
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-        var strObj = new String("bbq");
-        var preCheck = Object.isExtensible(strObj);
-        Object.preventExtensions(strObj);
+  var o  = {};
+  var o2 = undefined;
 
-        strObj.exName = 2;
-        return preCheck && !strObj.hasOwnProperty("exName");
-    }
+  o2 = Object.preventExtensions(o);
+  if (o2 === o && Object.isExtensible(o2) === false) {
+    return true;
+  }
+ }
 runTestCase(testcase);
