@@ -5,14 +5,18 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 8.12.1-1_1
-description: Properties - [[HasOwnProperty]] (property does not exist)
+es5id: 8.12.1-1_13
+description: >
+    Properties - [[HasOwnProperty]] (non-writable, non-configurable,
+    enumerable inherited value property)
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
 
-    var o = {};
+    var base = {};
+    Object.defineProperty(base, "foo", {value: 42, enumerable:true});
+    var o = Object.create(base);
     return o.hasOwnProperty("foo")===false;
 
 }
