@@ -5,16 +5,14 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 15.5.4.20-4-28
+es5id: 15.5.4.20-2-13
 description: >
-    String.prototype.trim handles whitepace and lineterminators
-    (\u000B\u000B)
+    String.prototype.trim - argument 'this' is a number that converts
+    to a string (value is 1(following 21 zeros))
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-  if ("\u000B\u000B".trim() === "") {
-    return true;
-  }
- }
+        return String.prototype.trim.call(1000000000000000000000) === "1e+21";
+    }
 runTestCase(testcase);
