@@ -5,16 +5,15 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 10.1.1-8-s
+es5id: 10.1.1-5-s
 description: >
     Strict Mode - Use Strict Directive Prologue is ''use strict';'
-    which appears twice in the directive prologue
+    which appears at the beginning of the block
 flags: [noStrict]
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-        "use strict";
         "use strict";
         try {
             eval("var public = 1;");
@@ -22,5 +21,6 @@ function testcase() {
         } catch (e) {
             return e instanceof SyntaxError;
         }
+
     }
 runTestCase(testcase);
