@@ -5,22 +5,24 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 11.2.3-3_6
+es5id: 11.2.3-3_8
 description: >
     Call arguments are evaluated before the check is made to see if
-    the object is actually callable (getter called)
-includes: [runTestCase.js]
+    the object is actually callable (global object)
+flags: [noStrict]
+includes:
+    - runTestCase.js
 ---*/
 
 function testcase() {
-    var o = { }; 
-    Object.defineProperty(o, "bar", {get: function()  {this.barGetter = true; return 42;}, 
-                                     set: function(x) {this.barSetter = true; }});
+    var fooCalled = false;
+    function foo(){ fooCalled = true; } 
+    
     try {
-        o.foo( o.bar );
-        $ERROR("o.foo does not exist!");
+        this.bar( foo() );
+        $ERROR("this.bar does not exist!");
     } catch(e) {
-        return (e instanceof TypeError) && (o.barGetter===true) && (o.barSetter===undefined);
+        return (e instanceof TypeError) && (fooCalled===true);
     }
 }
 runTestCase(testcase);
