@@ -5,32 +5,22 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 11.13.2-39-s
+es5id: 11.13.2-11-s
 description: >
-    Strict Mode - TypeError is thrown if The LeftHandSide of a
-    Compound Assignment operator(<<=) is a reference to an accessor
-    property with the attribute value {[[Set]]:undefined}
+    Strict Mode - ReferenceError is thrown if the
+    LeftHandSideExpression of a Compound Assignment operator(|=)
+    evaluates to an unresolvable reference
 flags: [onlyStrict]
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
         "use strict";
-        var obj = {};
-        Object.defineProperty(obj, "prop", {
-            get: function () {
-                return 11;
-            },
-            set: undefined,
-            enumerable: true,
-            configurable: true
-        });
-
         try {
-            obj.prop <<= 20;
+            eval("_11_13_2_11 |= 1;");
             return false;
         } catch (e) {
-            return e instanceof TypeError && obj.prop === 11;
+            return e instanceof ReferenceError;
         }
     }
 runTestCase(testcase);
