@@ -8,9 +8,9 @@ description: >
     base value is an environment record and environment record kind is
     object environment record. PutValue(lref, v) uses the initially
     created Reference even if the environment binding is no longer present.
-    No ReferenceError is thrown when 'x %= y' is in strict-mode code and the
+    No ReferenceError is thrown when 'x -= y' is in strict-mode code and the
     original binding is no longer present.
-    Check operator is "x %= y".
+    Check operator is "x -= y".
 includes:
     - fnGlobalObject.js
 ---*/
@@ -19,15 +19,15 @@ Object.defineProperty(fnGlobalObject(), "x", {
   configurable: true,
   get: function() {
     delete this.x;
-    return 5;
+    return 2;
   }
 });
 
 (function() {
   "use strict";
-  x %= 3;
+  x -= 1;
 })();
 
-if (fnGlobalObject().x !== 2) {
-  $ERROR('#1: fnGlobalObject().x === 2. Actual: ' + (fnGlobalObject().x));
+if (fnGlobalObject().x !== 1) {
+  $ERROR('#1: fnGlobalObject().x === 1. Actual: ' + (fnGlobalObject().x));
 }
