@@ -5,10 +5,10 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 11.4.1-5-a-18-s
+es5id: 11.4.1-3-a-1-s
 description: >
-    Strict Mode - SyntaxError is thrown when deleting a built-in
-    (Object)
+    Strict Mode - SyntaxError is thrown when deleting an un-resolvable
+    reference
 flags: [onlyStrict]
 includes: [runTestCase.js]
 ---*/
@@ -17,7 +17,7 @@ function testcase() {
         "use strict";
 
         try {
-            eval("delete Object;");
+            eval("delete obj");
             return false;
         } catch (e) {
             return e instanceof SyntaxError;
