@@ -5,19 +5,18 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 10.4.3-1-34gs
+es5id: 10.4.3-1-23gs
 description: >
-    Strict - checking 'this' from a global scope (FunctionExpression
-    defined within an Anonymous FunctionExpression inside strict mode)
+    Strict - checking 'this' from a global scope (New'ed object from
+    FunctionExpression defined within strict mode)
 flags: [onlyStrict]
+includes: [fnGlobalObject.js]
 ---*/
 
 "use strict";
-if (! ((function () {
-    var f = function () {
-        return typeof this;
-    }
-    return (f()==="undefined") && ((typeof this)==="undefined");
-})())) {
+var f = function () {
+    return this;
+}
+if (((new f()) === fnGlobalObject()) || (typeof (new f()) === "undefined")) {
     throw "'this' had incorrect value!";
 }
