@@ -5,23 +5,21 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 10.4.3-1-45-s
+es5id: 10.4.3-1-28-s
 description: >
-    Strict Mode - checking 'this' (FunctionDeclaration with a strict
-    directive prologue defined within a FunctionDeclaration)
-flags: [noStrict]
-includes:
-    - runTestCase.js
-    - fnGlobalObject.js
+    Strict Mode - checking 'this' (FunctionExpression defined within a
+    FunctionDeclaration inside strict mode)
+flags: [onlyStrict]
+includes: [runTestCase.js]
 ---*/
 
 function testcase() {
+"use strict";
 function f1() {
-    function f() {
-        "use strict";
+    var f = function () {
         return typeof this;
     }
-    return (f()==="undefined") && (this===fnGlobalObject());
+    return (f()==="undefined") && ((typeof this)==="undefined");
 }
 return f1();
 }
