@@ -5,10 +5,10 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 7.6.1-20-s
+es5id: 7.6.1.2-7-s
 description: >
-    7.6 - SyntaxError expected: reserved words used as Identifier
-    Names in UTF8: \u0070\u0075\u0062\u006c\u0069\u0063 (public)
+    Strict Mode - SyntaxError is thrown when FutureReservedWord
+    'package' occurs in strict mode code
 flags: [onlyStrict]
 includes: [runTestCase.js]
 ---*/
@@ -17,7 +17,7 @@ function testcase() {
         "use strict";
 
         try {
-            eval("var \u0070\u0075\u0062\u006c\u0069\u0063 = 123;");
+            eval("var package = 1;");
             return false;
         } catch (e) {
             return e instanceof SyntaxError;
