@@ -2,10 +2,10 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-info: The "function" token can not be used as identifier
-es5id: 7.6.1.1_A1.11
-description: Checking if execution of "function=1" fails
+info: The "typeof" token can not be used as identifier
+es5id: 7.6.1.1_A1.21
+description: Checking if execution of "typeof=1" fails
 negative: SyntaxError
 ---*/
 
-function = 1;
+typeof = 1;
