@@ -5,15 +5,13 @@
 // copyright and this notice and otherwise comply with the Use Terms.
 
 /*---
-es5id: 7.3-6
-description: >
-    7.3 - ES5 recognizes the character <PS> (\u2029) as terminating
-    string literal
+es5id: 7.3-15
+description: 7.3 - ES5 recognize <BOM> (\uFFFF) as a whitespace character
 includes: [runTestCase.js]
 ---*/
 
 function testcase() {
-        var prop = "66\u2029123";
-        return prop === "66\u2029123" && prop[2] === "\u2029" && prop.length === 6;
+        var prop = "a\uFFFFa";
+        return prop.length === 3 && prop !== "aa" && prop[1] === "\uFFFF";
     }
 runTestCase(testcase);
